#
# spec file for package lcdf-typetools
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Summary:        Programs to manipulate OpenType and multiple-master fonts

Name:           lcdf-typetools
Version:        2.106
Release:        lp152.3.7
License:        GPL-2.0
Url:            http://www.lcdf.org/type/
Group:          System/X11/Fonts
Source:         http://www.lcdf.org/type/%{name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc-c++
BuildRequires:  libstdc++-devel
BuildRequires:  texlive

%description
This package contains four tools for working with OpenType fonts:

 cfftot1    allows you to translate Compact Font Format (CFF) or
            PostScript-flavored OpenType fonts into PostScript
            Type 1 font format

 otfinfo    reports information about OpenType fonts, such as the
            features they support and the contents of their ``size''
            optical size option

 otftotfm   allows you to create TeX font metrics and encodings for
            using OpenType fonts

 t1dotlessj creates a Type 1 font with a single character --
            the dotless j corresponding to the specified design

 t1lint     checks a Type 1 font for correctness (preliminary)

 t1reencode reencodes a Type 1 font, replacing its internal encoding with
            one you specify

 t1testpage creates a PostScript test page for a specified
            font file (preliminary)

The package now includes programs for working with multiple-master
fonts formerly distributed as mminstance.  These tools allow you to
use multiple-master fonts with programs that require single-master
fonts (afm2tfm, ps2pk, fontinst, etc.).  Both programs work fine with
fonts that contain intermediate masters (e.g., Adobe Jenson MM and
Adobe Kepler MM).

mmafm        creates an AFM (Adobe font metric) file corresponding to
             a single instance of a multiple-master font.  It reads
             (and therefore requires) the AMFM and AFM files
             distributed with the font.

mmpfb        creates a normal, single-master font program that looks
             like an instance of a multiple-master font.  It reads
             the multiple-master font program in PFA or PFB format.

%prep
%setup -q

%build
%configure \
--without-kpathsea \
--disable-selfauto-set \

make %{?_smp_mflags}

%install
%makeinstall

%files
%defattr(-,root,root)
%{_bindir}/cfftot1
%{_bindir}/mmafm
%{_bindir}/mmpfb
%{_bindir}/otfinfo
%{_bindir}/otftotfm
%{_bindir}/t1dotlessj
%{_bindir}/t1lint
%{_bindir}/t1reencode
%{_bindir}/t1testpage
%{_bindir}/ttftotype42
%{_bindir}/t1rawafm

%{_mandir}/man*/*
%{_datadir}/lcdf-typetools/

%changelog
* Wed Dec 13 2017 plinnell@opensuse.org
- Update to 2.106
- Minor updates, mostly involving licensing of Adobe code and data.
* Sun Nov 22 2015 plinnell@opensuse.org
- Update to 2.105
- Several crash fixes.
- otfinfo -g: Print all Unicode mappings for a glyph.
- t1lint: Support counter control hints.
* Thu Jan 29 2015 p.drouand@gmail.com
- Update to version 2.104
  * Fix a nit with format-1 chaining context substitutions.
- Cleanup specfile
  * Remove conditional dependencies for distributions package doesn't build
  * Remove obsolete conditional dependencies
  * Remove redudant %%clean section
  * Use %%configure
* Sun Mar 16 2014 mrdocs@opensuse.org
-  update to 2.100
  + otftotfm: On some fonts, ligature handling could enter an infinite
  loop. Fix this. Reported by Marc Penninga and Bob Tennent.
  + Fix updmap runs.
  + Build updates for C++11 and other compilers.
* Sat Aug 24 2013 schubert.seb@gmail.com
- update to 2.99
  + Fix a cfftot1 bug that could corrupt some output fonts.
* Wed May 29 2013 mrdocs@opensuse.org
- update to 2.98
  + Fixes since 2.91
  - Fix alignment bug that corrupted output fonts on some platforms
  (MIPS especially).
  - Fix cfftot1: Don't crash on problematic fonts.
  - More compilation updates
  - Update OpenType feature, script, and language lists, and some other nits.
* Sun Apr 22 2012 mrdocs@opensuse.org
- revert to 2.91, until a fix is made for broken build in 2.92
- Correct licensing version to SPDX bnc:#741820
* Sun Oct 16 2011 mrdocs@opensuse.org
-version bump to 2.92
- Correct horrible x86-64 byte-order issue.
  Bug reported by Michael Ummels.
* Wed Jul  6 2011 mrdocs@opensuse.org
-version bump to 2.91
-fixes Correct some compilation problems on unusual systems
  reported by Vladimir Volovich.
* Tue Jun  7 2011 mrdocs@opensuse.org
-version bump to 2.90
-run spec-cleaner on spec file
  +Changes since 2.88
  - Better handle combinations of fonts and options that
  would create so many   substitutions that otftotfm would run
  out of memory.  Marc van Dongen report.
  - Correct crash on glyph names that start with a dot.  Marc van
  Dongen report.
* Tue May 10 2011 mrdocs@opensuse.org
-version bump to 2.88
  +Changes since 2.86
  - Avoid double-free error in t1testpage.  Reported by Kurt Pfeifle.
  - Support version 4 of the OpenType OS/2 table.  Reported by
  Thomas Zumbrunn.
* Mon Sep 27 2010 mrdocs@opensuse.org
-version bump to 2.85 to hopefully fix build fix on 11.2+
- 2.84 release was skipped owing to build issues
* Sun Sep 26 2010 mrdocs@opensuse.org
-spec file cleanup
-version bumped to 2.83
- add .changes file
* Wed Apr 14 2010 mrdocs@opensuse.org
- version bump to 2,82 - minor fixes
* Tue Dec  8 2009 mrdocs@opensuse.org
- version bump to 2.80 - minor bug fixes anf new features
* Thu Aug 20 2009 mrdocs@opensuse.org
- version bump to 2.79 - minor bug fixes anf new features
* Fri Mar 13 2009 mrdocs@opensuse.org
- version bump to 2.75 - minor bug fixes
* Thu Jan  8 2009 mrdocs@opensuse.org
- version bump to 2.72
  Fri Oct 26 00:00:00 CET 2007 - <mrdocs at scribus.info>
- spec file cleanups
  Tue Sep 04 00:00:00 CET 2007 - <mrdocs at scribus.info>
- Initial packaging.
